@@ -17,8 +17,7 @@ class DetectObject(object):
         self.model = attempt_load(self.weights, map_location=self.device)
         self.model.to(self.device).eval()
 
-    def detect(self, img_path):
-        im0s = cv2.imread(img_path)
+    def detect(self, im0s):
         img = letterbox(im0s, new_shape=self.img_size)[0]
         img = img[:, :, ::-1].transpose(2, 0, 1)
         img = np.ascontiguousarray(img)
